@@ -32,8 +32,9 @@ def parse_ahb_expression_to_single_requirement_indicator_expressions(ahb_express
     PREFIX_OPERATOR: "X"i | "O"i | "U"i
     MODAL_MARK: /M(uss)?|S(oll)?|K(ann)?/i
     // Matches if it looks like a condition expression, but does not yet check if it is a syntactically valid one:
-    CONDITION_EXPRESSION: /(?!\BU\B)[\[\]\(\)U∧O∨X⊻\d\s]+/i
+    CONDITION_EXPRESSION: /(?!\BU\B)[\[\]\(\)U∧O∨X⊻\d\sP]+/i
     """
+    # todo: implement wiederholbarkeiten
     # Regarding the negative lookahead in the condition expression regex see examples https://regex101.com/r/6fFHD4/1
     # and CTRL+F for "Mus[2]" in the unittest that fails if you remove the lookahead.
     parser = Lark(grammar, start="ahb_expression")
