@@ -3,6 +3,8 @@ from lark import Token, Tree
 
 from ahbicht.expressions.expression_resolver import parse_expression_including_unresolved_subexpressions
 
+pytestmark = pytest.mark.asyncio
+
 
 class TestExpressionResolver:
     @pytest.mark.parametrize(
@@ -20,15 +22,18 @@ class TestExpressionResolver:
                                 Tree(
                                     "and_composition",
                                     [
-                                        Tree("condition_key", [Token("INT", "3")]),
-                                        Tree("condition_key", [Token("INT", "4")]),
+                                        Tree("condition", [Token("CONDITION_KEY", "3")]),
+                                        Tree("condition", [Token("CONDITION_KEY", "4")]),
                                     ],
                                 ),
                             ],
                         ),
                         Tree(
                             "single_requirement_indicator_expression",
-                            [Token("MODAL_MARK", "Soll"), Tree("condition_key", [Token("INT", "5")])],
+                            [
+                                Token("MODAL_MARK", "Soll"),
+                                Tree("condition", [Token("CONDITION_KEY", "5")]),
+                            ],
                         ),
                     ],
                 ),
@@ -45,8 +50,8 @@ class TestExpressionResolver:
                                 Tree(
                                     "or_composition",
                                     [
-                                        Tree("condition_key", [Token("INT", "504")]),
-                                        Tree("condition_key", [Token("INT", "6")]),
+                                        Tree("condition", [Token("CONDITION_KEY", "504")]),
+                                        Tree("condition", [Token("CONDITION_KEY", "6")]),
                                     ],
                                 ),
                             ],
@@ -59,12 +64,12 @@ class TestExpressionResolver:
                 Tree(
                     "then_also_composition",
                     [
-                        Tree("condition_key", [Token("INT", "905")]),
+                        Tree("condition", [Token("CONDITION_KEY", "905")]),
                         Tree(
                             "and_composition",
                             [
-                                Tree("condition_key", [Token("INT", "504")]),
-                                Tree("condition_key", [Token("INT", "6")]),
+                                Tree("condition", [Token("CONDITION_KEY", "504")]),
+                                Tree("condition", [Token("CONDITION_KEY", "6")]),
                             ],
                         ),
                     ],
@@ -72,8 +77,8 @@ class TestExpressionResolver:
             ),
         ],
     )
-    def test_expression_resolver_valid(self, expression: str, expected_tree: Tree):
-        actual_tree = parse_expression_including_unresolved_subexpressions(expression)
+    async def test_expression_resolver_valid(self, expression: str, expected_tree: Tree):
+        actual_tree = await parse_expression_including_unresolved_subexpressions(expression)
         assert actual_tree == expected_tree
 
     @pytest.mark.parametrize(
@@ -84,9 +89,9 @@ class TestExpressionResolver:
             ),
         ],
     )
-    def test_expression_resolver_failing(self, expression: str):
+    async def test_expression_resolver_failing(self, expression: str):
         with pytest.raises(SyntaxError) as excinfo:
-            parse_expression_including_unresolved_subexpressions(expression)
+            await parse_expression_including_unresolved_subexpressions(expression)
 
         assert """Please make sure that the ahb_expression starts with a requirement indicator \
 (i.e Muss/M, Soll/S, Kann/K, X, O, U) and the condition expressions consist of only \
@@ -96,9 +101,11 @@ the following characters: [ ] ( ) U ∧ O ∨ X ⊻ and digits.""" in str(
 
         assert """Please make sure that:
              * all conditions have the form [INT]
+             * all packages have the form [INTP]
              * no conditions are empty
              * all compositions are combined by operators 'U'/'O'/'X' or without an operator
              * all open brackets are closed again and vice versa
              """ in str(
             excinfo.value
         )
+        # todo: implement wiederholbarkeiten
